Module error

Module error 

Structs

HenDiagnostic
HenDiagnosticLocation
HenDiagnosticPosition
HenDiagnosticRange
HenDiagnosticRelatedInformation
HenDiagnosticSuggestion
HenDiagnosticSymbol
HenError
Application error with a short summary and optional detail lines.

Enums

HenDiagnosticPhase
HenDiagnosticSeverity
HenErrorKind
High-level classification for hen errors to aid structured reporting.

Functions

print_error
Render an error to stderr using the structured format.

Type Aliases

HenResult
Alias for results that return a HenError.