Structs
- HenDiagnostic
- HenDiagnostic
Location - HenDiagnostic
Position - HenDiagnostic
Range - HenDiagnostic
Related Information - HenDiagnostic
Suggestion - HenDiagnostic
Symbol - HenError
- Application error with a short summary and optional detail lines.
Enums
- HenDiagnostic
Phase - HenDiagnostic
Severity - HenError
Kind - High-level classification for hen errors to aid structured reporting.
Functions
- print_
error - Render an error to stderr using the structured format.
Type Aliases
- HenResult
- Alias for results that return a
HenError.